==> zio-aws-ec2_2.13-5.17.125.1-sources.jar: zio/aws/ec2/model/CreateReservedInstancesListingResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateReservedInstancesListingResponse(
    reservedInstancesListings: Option[
      Iterable[zio.aws.ec2.model.ReservedInstancesListing]
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.CreateReservedInstancesListingResponse = {
    import CreateReservedInstancesListingResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.CreateReservedInstancesListingResponse
      .builder()
      .optionallyWith(
        reservedInstancesListings.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.reservedInstancesListings)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.CreateReservedInstancesListingResponse.ReadOnly =
    zio.aws.ec2.model.CreateReservedInstancesListingResponse
      .wrap(buildAwsValue())
}
object CreateReservedInstancesListingResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.CreateReservedInstancesListingResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.CreateReservedInstancesListingResponse =
      zio.aws.ec2.model.CreateReservedInstancesListingResponse(
        reservedInstancesListings.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def reservedInstancesListings
        : Option[List[zio.aws.ec2.model.ReservedInstancesListing.ReadOnly]]
    def getReservedInstancesListings: ZIO[Any, AwsError, List[
      zio.aws.ec2.model.ReservedInstancesListing.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "reservedInstancesListings",
      reservedInstancesListings
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.CreateReservedInstancesListingResponse
  ) extends zio.aws.ec2.model.CreateReservedInstancesListingResponse.ReadOnly {
    override val reservedInstancesListings
        : Option[List[zio.aws.ec2.model.ReservedInstancesListing.ReadOnly]] =
      scala
        .Option(impl.reservedInstancesListings())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.ReservedInstancesListing.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.CreateReservedInstancesListingResponse
  ): zio.aws.ec2.model.CreateReservedInstancesListingResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-7.21.15.12-sources.jar: zio/aws/ec2/model/CreateReservedInstancesListingResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateReservedInstancesListingResponse(
    reservedInstancesListings: Optional[
      Iterable[zio.aws.ec2.model.ReservedInstancesListing]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.CreateReservedInstancesListingResponse = {
    import CreateReservedInstancesListingResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.CreateReservedInstancesListingResponse
      .builder()
      .optionallyWith(
        reservedInstancesListings.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.reservedInstancesListings)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.CreateReservedInstancesListingResponse.ReadOnly =
    zio.aws.ec2.model.CreateReservedInstancesListingResponse
      .wrap(buildAwsValue())
}
object CreateReservedInstancesListingResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.CreateReservedInstancesListingResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.CreateReservedInstancesListingResponse =
      zio.aws.ec2.model.CreateReservedInstancesListingResponse(
        reservedInstancesListings.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def reservedInstancesListings
        : Optional[List[zio.aws.ec2.model.ReservedInstancesListing.ReadOnly]]
    def getReservedInstancesListings: ZIO[Any, AwsError, List[
      zio.aws.ec2.model.ReservedInstancesListing.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "reservedInstancesListings",
      reservedInstancesListings
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.CreateReservedInstancesListingResponse
  ) extends zio.aws.ec2.model.CreateReservedInstancesListingResponse.ReadOnly {
    override val reservedInstancesListings
        : Optional[List[zio.aws.ec2.model.ReservedInstancesListing.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.reservedInstancesListings())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.ReservedInstancesListing.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.CreateReservedInstancesListingResponse
  ): zio.aws.ec2.model.CreateReservedInstancesListingResponse.ReadOnly =
    new Wrapper(impl)
}
